@@ -1,7 +1,6 @@
 #!/usr/bin/perl
 
 use lib '/users/staff/leithdo/perl5/lib/perl5/';
-use Bib::CrossRef;
 use Bib::Tools;
 use CGI;
 use CGI::Carp qw(warningsToBrowser fatalsToBrowser); 
@@ -17,15 +16,24 @@ $orcid = $1;
 if (length($orcid) > 5) {
   $refs->add_orcid($1);
 } 
+
 my $google = scalar $q->param('google'); #NB: CGI has already carried out URL decoding
-if (length($google) > 5) {
+if (length($google) > 15) {
   if (!($google =~ m/^http/)) { $google = "http://".$google;}
-  $refs->add_google($google);
+  if ($google =~ m/https?:\/\/scholar.google.com/) {
+    $refs->add_google($google);
+  } else {
+    print "<p style='color:red'>google url looks invalid: ", $google,"</p>";
+  }
 }
 my $google2 = scalar $q->param('google2'); #NB: CGI has already carried out URL decoding
-if (length($google2) > 5) {
+if (length($google2) > 15) {
   if (!($google2 =~ m/^http/)) { $google2 = "http://".$google2;}
-  $refs->add_google_search($google2);
+  if ($google2 =~ m/https?:\/\/scholar.google.com/) {
+    $refs->add_google_search($google2);
+  } else {
+    print "<p style='color:red'>google url looks invalid: ", $google2,"</p>";
+  }
 }
 my $dblp = scalar $q->param('dblp');
 if (length($dblp) > 5) {
@@ -36,6 +44,12 @@ my $pubmed = scalar $q->param('pubmed');
 if (length($pubmed) > 5) {
   $refs->add_pubmed($pubmed);
 }
+
+$filename = scalar $q->param('bibtex');
+$tmpfilename = $q->tmpFileName($filename);
+open my $fh, "<", $tmpfilename;
+$refs->add_bibtex($fh);
+
 my @values = $q->multi_param('refs');
 foreach my $value (@values) {
   #NB: CGI has already carried out URL decoding
